@@ -50,6 +50,10 @@ class _HydraulicCrossSectionStation(_Model):
         ..., description="Station distance from left bank when looking downstream"
     )
     z: float = Field(..., description="Station elevation")
+    roughness_correction: Optional[float] = Field(
+        None,
+        description="Local roughness correction (acts as multiplier on base roughness)",
+    )
 
 
 class _HydraulicLongitudinalStation(_Model):
