@@ -1,6 +1,6 @@
-from typing import List
+from typing import List, Any
 
-from pydantic import Field
+from pydantic import Field, validator
 
 from kisters.network_store.model_library.base import BaseNode as _BaseNode
 from kisters.network_store.model_library.base import Model as _Model
@@ -30,3 +30,10 @@ class _StorageLevelVolume(_Model):
 class Storage(_Node):
     element_class: str = Field("Storage", const=True)
     level_volume: List[_StorageLevelVolume] = Field(..., min_items=2)
+
+    @validator("level_volume")
+    def check_monotonic(cls, v: Any) -> Any:
+        volumes = [d.volume for d in v]
+        if not all(a < b for a, b in zip(volumes, volumes[1:])):
+            raise ValueError("Volume must be specified in strictly increasing order")
+        return v
